@@ -13,11 +13,11 @@ class TaiwanAddressAnalizer:
         self.TWaddPatDICT = {"countyPat"      : "[^\s][^市]縣",
                              "cityPat"        : "[^是在於及、，\s]{1,2}市",
                              "districtPat"    : "那瑪夏區|[^市及、，\s]+?.社?區|[東西南北中]區",
-                             "townshipPat"    : "(阿里山|三地門|太麻里)鄉|..[鄉里]",
+                             "townshipPat"    : "(阿里山|三地門|太麻里)鄉|..鄉|[^縣].里(?!區)",
                              "townPat"        : "[^\s][^\s]鎮",
-                             "villagePat"     : "[^\s][^\s]村",
+                             "villagePat"     : "[^\s][^\s]新?村(?!路)",
                              "neighborhoodPat": "(\s?[零一二三四五六七八九十廿卅０-９\d]+?\s?鄰)",
-                             "roadPat"        : "市府路|市[政場]([北南中]|[1-7一二三四五六七]){0,2}路|市港[^\s]路|[新環村盛果]市[^\s]?[路街]|市民大道|市宅街|[埔菜美元西]市[路街]|(?<=[縣市區鄉鎮里村鄰])[^市區鄉鎮村路及鄰、，]{1,4}([路街]|大道)",
+                             "roadPat"        : "市府路|市[政場]([北南中]|[1-7一二三四五六七]){0,2}路|市港[^\s]路|美村路|[新環村盛果]市[^\s]?[路街]|市民大道|市宅街|[埔菜美元西]市[路街]|(?<=[縣市區鄉鎮里村鄰])[^市區鄉鎮村路及鄰、，]{1,4}([路街](?!里)|大道)",
                              "sectionPat"     : "\s?[零一二三四五六七八九十廿卅百０-９\d]*?\s?段",
                              "alleyPat"       : "(國中|市場|新市.|([^縣市區鄉鎮里村路街段]{1,2}|鐵路)[零一二三四五六七八九十廿卅百０-９\d]*?|\s?[零一二三四五六七八九十廿卅百０-９\d]*?)\s?巷([零一二三四五六七八九十廿卅百０-９\d]*?\s?弄)?",
                              "numberPat"      : "(\s?[零一二三四五六七八九十廿卅百０-９\d]*?\s?[之\-]\s?)?\s?[零一二三四五六七八九十廿卅百０-９\d]*?\s?號([之\-]\s?[零一二三四五六七八九十廿卅百０-９\d]+?)?",
